Sample
--------

.. currentmodule:: prismstudio

.. autosummary::
    :toctree: api/

    _PrismComponent.sample_pct_change
    _PrismComponent.sample_shift
    _PrismComponent.sample_diff
    _PrismComponent.sample_max
    _PrismComponent.sample_min
    _PrismComponent.sample_mean
    _PrismComponent.sample_ewma
    _PrismComponent.sample_ewmstd
    _PrismComponent.sample_ewmvar
    _PrismComponent.sample_median
    _PrismComponent.sample_sum
    _PrismComponent.sample_std
    _PrismComponent.sample_var
    _PrismComponent.sample_z_score
    _PrismComponent.sample_skew

